@@ -24,14 +24,15 @@ from azure.identity import DefaultAzureCredential
 from azure.keyvault.secrets import SecretClient
 
 from airflow.compat.functools import cached_property
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.secrets import BaseSecretsBackend
 from airflow.utils.log.logging_mixin import LoggingMixin
 from airflow.version import version as airflow_version
 
 
 def _parse_version(val):
-    val = re.sub(r'(\d+\.\d+\.\d+).*', lambda x: x.group(1), val)
-    return tuple(int(x) for x in val.split('.'))
+    val = re.sub(r"(\d+\.\d+\.\d+).*", lambda x: x.group(1), val)
+    return tuple(int(x) for x in val.split("."))
 
 
 class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
@@ -73,11 +74,11 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
 
     def __init__(
         self,
-        connections_prefix: str = 'airflow-connections',
-        variables_prefix: str = 'airflow-variables',
-        config_prefix: str = 'airflow-config',
-        vault_url: str = '',
-        sep: str = '-',
+        connections_prefix: str = "airflow-connections",
+        variables_prefix: str = "airflow-variables",
+        config_prefix: str = "airflow-config",
+        vault_url: str = "",
+        sep: str = "-",
         **kwargs,
     ) -> None:
         super().__init__()
@@ -128,7 +129,7 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
             warnings.warn(
                 f"Method `{self.__class__.__name__}.get_conn_uri` is deprecated and will be removed "
                 "in a future release.  Please use method `get_conn_value` instead.",
-                DeprecationWarning,
+                AirflowProviderDeprecationWarning,
                 stacklevel=2,
             )
         return self.get_conn_value(conn_id)
@@ -158,7 +159,7 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
         return self._get_secret(self.config_prefix, key)
 
     @staticmethod
-    def build_path(path_prefix: str, secret_id: str, sep: str = '-') -> str:
+    def build_path(path_prefix: str, secret_id: str, sep: str = "-") -> str:
         """
         Given a path_prefix and secret_id, build a valid secret name for the Azure Key Vault Backend.
         Also replaces underscore in the path with dashes to support easy switching between
@@ -168,8 +169,12 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
         :param secret_id: Name of the secret
         :param sep: Separator used to concatenate path_prefix and secret_id
         """
-        path = f'{path_prefix}{sep}{secret_id}'
-        return path.replace('_', sep)
+        # When an empty prefix is given, do not add a separator to the secret name
+        if path_prefix == "":
+            path = f"{secret_id}"
+        else:
+            path = f"{path_prefix}{sep}{secret_id}"
+        return path.replace("_", sep)
 
     def _get_secret(self, path_prefix: str, secret_id: str) -> str | None:
         """
@@ -183,5 +188,5 @@ class AzureKeyVaultBackend(BaseSecretsBackend, LoggingMixin):
             secret = self.client.get_secret(name=name)
             return secret.value
         except ResourceNotFoundError as ex:
-            self.log.debug('Secret %s not found: %s', name, ex)
+            self.log.debug("Secret %s not found: %s", name, ex)
             return None
